@@ -1,13 +1,12 @@
 # flake8: noqa
 from ._version import __version__
-from .helpers import dump_dfs_to_tables
+from .artifact_context import dump_dfs_to_tables
 from .invoke_commands import dataset_ns, project_ns
-from .metadata.bases import (
+from .metadata.datascript import (
     BaseEntity,
     CompositeTypeBase,
     IndexBase,
     TableFeaturesBase,
 )
-from .metadata.type_hinting import Col
+from .metadata.datascript.scrutable import ScruTable, TableFactory
 from .pipeline_registry import PipelineRegistry
-from .scrutable_class import ScruTable, TableFactory
